@@ -4,6 +4,7 @@
 from functools import wraps
 from sqlalchemy.exc import SQLAlchemyError
 from sdc_helpers.slack_helper import SlackHelper
+from sdc_helpers.utils import extract_stack_trace
 
 
 def query_exception_handler(exceptions: tuple = (SQLAlchemyError, )):
@@ -71,9 +72,12 @@ def general_exception_handler(
                 return function(*args, **kwargs)
 
             except exceptions as ex:
+
+                # get stack trace
+                stack_trace = extract_stack_trace()
                 # reformat log
                 reformatted_log_msg = (
-                    'Server Error: {ex}'.format(ex=str(ex))
+                    'Server Error: {ex}'.format(ex=stack_trace)
                 )
 
                 # emit log
