@@ -107,7 +107,12 @@ class QueryHelper:
         self.session.close()
         del self.redis_helper
 
-    def get_query(self, model_class, for_update: bool = False) -> Query:
+    def get_query(
+            self,
+            model_class,
+            for_update: bool = False,
+            no_wait: bool = False
+    ) -> Query:
         """
             Get a query for a model class
 
@@ -115,6 +120,7 @@ class QueryHelper:
                 model_class: The model class to query on
                 for_update (bool): Reserve the model for exclusive use until
                                    commit or session is closed - Default False
+                no_wait (bool): Don't wait around for a model if it is locked
             return:
                 query (Query) : Return a SQLAlchemy Query object
 
@@ -131,7 +137,7 @@ class QueryHelper:
         )
 
         if for_update:
-            query = query.with_for_update(nowait=True)
+            query = query.with_for_update(nowait=no_wait)
 
         return query
 
